
use Test::More  'no_plan';
BEGIN { use_ok('Telephone::Mnemonic::US') };
BEGIN { use_ok('Telephone::Mnemonic::US::Math') };
BEGIN { use_ok('Telephone::Mnemonic::US::Number') };
BEGIN { use_ok('Telephone::Mnemonic::Phone') };
BEGIN { use_ok('Telephone::Mnemonic::US::Phone') };
BEGIN { use_ok('Telephone::Mnemonic::US::Words') };
